#
# spec file for package f3d
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define c_lib   libf3d3
Name:           f3d
Version:        3.2.0
Release:        1.1
Summary:        Fast and minimalist 3D viewer
License:        BSD-3-Clause
Group:          Productivity/Graphics/Viewers
URL:            https://f3d.app
Source0:        https://github.com/%{name}-app/%{name}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         help.patch
BuildRequires:  cmake
BuildRequires:  fast_float-devel
BuildRequires:  fmt-devel
BuildRequires:  help2man
BuildRequires:  pkgconfig
BuildRequires:  cmake(Alembic)
BuildRequires:  cmake(Imath)
BuildRequires:  cmake(OpenCASCADE)
BuildRequires:  cmake(vtk) >= 9.3
BuildRequires:  pkgconfig(assimp)
BuildRequires:  pkgconfig(draco)
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xt)
%if 0%{?sle_version} >= 150400
BuildRequires:  gcc11-c++
%else
BuildRequires:  gcc-c++
%endif

%description
F3D is a VTK-based 3D viewer following the KISS principle, so it is
minimalist, efficient, has no GUI, has simple interaction mechanisms and is
fully controllable using arguments in the command line.

%package        bash-completion
Summary:        Bash completion for %{name}
Group:          System/Shells
Requires:       bash-completion
Supplements:    (%{name} and bash)
BuildArch:      noarch

%description    bash-completion
Bash command line completion support for %{name}.

%package        fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       fish
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description    fish-completion
Fish command line completion support for %{name}.

%package        zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       zsh
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description    zsh-completion
ZSH command line completion support for %{name}.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{c_lib} = %{version}

%description devel
Development files and headers for %{name}

%package -n %{c_lib}
Summary:        F3d library
Group:          System/Libraries

%description -n %{c_lib}
Library for f3d.

%prep
%autosetup -p1

%build
%cmake \
%if 0%{?suse_version} < 1600
    -DCMAKE_INSTALL_DOCDIR:PATH=%{_docdir}/%{name} \
%endif
    -DCMAKE_SKIP_INSTALL_RPATH=ON \
    -DCMAKE_BUILD_WITH_INSTALL_RPATH=ON \
    -DBUILD_TESTING=OFF \
    -DF3D_BINDINGS_JAVA=OFF \
    -DF3D_BINDINGS_PYTHON=OFF \
    -DF3D_LINUX_LINK_FILESYSTEM=ON \
    -DF3D_LINUX_GENERATE_MAN=ON \
    -DF3D_LINUX_INSTALL_DEFAULT_CONFIGURATION_FILE_IN_PREFIX=ON \
    -DF3D_MODULE_EXTERNAL_RENDERING=OFF \
    -DF3D_MODULE_RAYTRACING=OFF \
    -DF3D_PLUGINS_STATIC_BUILD=OFF \
%if 0%{?sle_version} >= 150400
    -DCMAKE_CXX_COMPILER=%{_bindir}/g++-11 \
%endif
    -DF3D_PLUGIN_BUILD_ALEMBIC=ON \
    -DF3D_PLUGIN_BUILD_ASSIMP=ON \
    -DF3D_PLUGIN_BUILD_DRACO=OFF \
    -DF3D_PLUGIN_BUILD_EXODUS=ON \
    -DF3D_PLUGIN_BUILD_OCCT=ON
%cmake_build

%install
%cmake_install
rm -rfv %{buildroot}%{_docdir}/f3d

# this is needed so f3d autoloads the plugins for those filetypes specified in the configs
mkdir -p %{buildroot}%{_sysconfdir}/f3d/config.d
install -Dm644 plugins/assimp/configs/config.d/10_assimp.json %{buildroot}%{_sysconfdir}/f3d/config.d/10_assimp.json
install -Dm644 plugins/alembic/configs/config.d/10_alembic.json %{buildroot}%{_sysconfdir}/f3d/config.d/10_alembic.json
#install -Dm644 plugins/exodus/configs/config.d/10_exodus.json %{buildroot}%{_sysconfdir}/f3d/config.d/10_exodus.json
install -Dm644 plugins/native/configs/config.d/10_native.json %{buildroot}%{_sysconfdir}/f3d/config.d/10_native.json
install -Dm644 plugins/occt/configs/config.d/10_occt.json %{buildroot}%{_sysconfdir}/f3d/config.d/10_occt.json

%post -n %{c_lib} -p /sbin/ldconfig
%postun -n %{c_lib} -p /sbin/ldconfig

%files
%doc README.md
%license LICENSE.md doc/THIRD_PARTY_LICENSES.md
%{_bindir}/%{name}
%{_libdir}/lib%{name}-plugin-*.so
%{_datadir}/applications/%{name}.desktop
%{_datadir}/applications/%{name}-plugin-*.desktop
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/plugins
%{_datadir}/%{name}/plugins/*.json
%{_datadir}/icons/hicolor/*/apps/%{name}.??g
%dir %{_datadir}/icons/HighContrast
%dir %{_datadir}/icons/HighContrast/scalable
%dir %{_datadir}/icons/HighContrast/scalable/apps
%{_datadir}/icons/HighContrast/scalable/apps/f3d.svg
%{_datadir}/metainfo/app.%{name}.F3D.metainfo.xml
%dir %{_datadir}/thumbnailers
%{_datadir}/thumbnailers/%{name}*.thumbnailer
%{_mandir}/man?/%{name}.?%{?ext_man}
%dir %{_sysconfdir}/f3d
%dir %{_sysconfdir}/f3d/config.d
%config %{_sysconfdir}/f3d/config.d/*.json
%{_libdir}/libvtkext.so

%files devel
%doc README.md
%license LICENSE.md doc/THIRD_PARTY_LICENSES.md
%{_libdir}/lib%{name}.so

%files -n %{c_lib}
%{_libdir}/lib%{name}.so.*

%files bash-completion
%dir %{_datadir}/bash-completion/
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/%{name}

%files fish-completion
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/%{name}.fish

%files zsh-completion
%dir %{_datadir}/zsh/
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_%{name}

%changelog
* Wed Jul  9 2025 Michael Vetter <mvetter@suse.com>
- Update to 3.2.0:
  * Fix artifacts with spherical harmonics (#2367)
  * scene: Fix a crash when switching from a invalid file (#2368)
  * animationManager: stop playing animation when there is none available (#2365)
  * Change imgui style to match official F3D palette (#2359)
  * Feature: Add yaw camera support  (#2357)
  * Revert "Fix incorrect usage of internal variable PACKAGE_PREFIX_DIR (#1377)" (#2362)
  * Add support for 3DGS .ply files (#2256)
  * Improve VCPKG and CMake presets (#2356)
  * Feature/improve visual studio and vcpkg integration (#2298)
  * feat: Add F3D splat reader stream support and test (#2351)
  * [Fix]  Verbose level update dynamic options (#2350)
  * libf3d: Introduce animation.indices (#2261)
  * Add bounties to CONTRIBUTING (#2287)
  * Add netcdf support (#2335)
  * [Feature] Add binding and command for cycling verbose level (#2324)
  * Application: Fix an issue when switching file with optional config CLI options (#2329)
  * substitute `Sequence[...]` for `list[...]` parameters in stubs (#2322)
  * add `py.typed` file to Python module (#2323)
  * Exclude assimp from sanitizer testing and update VTK (#2313)
  * Add external navigation link to F3D libf3d doxygen in config.yml (#2319)
  * App: fixed crash when no file was selected in dialog (#2315)
  * Updating VTK
  * Assimp: Exclude some tests failing with sanitizer
  * fix: improve help(f3d) (#2299)
  * Implements texture transforms (#2282)
  * configs: Use glob in config files where it make sense (#2295)
  * App: Fix a order logic issue in F3DConfigFileTools (#2288)
  * ForceReader: Support invalid extensions (#2294)
  * hdf: Add missing exodus extensions (#2293)
  * Cli reader options (#1860)
  * Fix assimp 6.0 configuration
  * Add support for extended ascii and UTF8 username (#2277)
  * Config glob matching (#2281)
  * add armor.mdl to DATA_LICENSES.md (#2280)
  * vtkF3DRenderer: Fix small issues with colormap discretization (#2276)
  * Use flag to prevent drop zone to "steal" all scrolling (#2272)
  * doc: Update opengraph image (#2271)
  * doc: fix small typos (#2270)
  * Select mdl skin (#2252)
  * Feature: colormap discretization (#2264)
  * Fix doc formatting (#2269)
  * doc: Update min dependencies (#2267)
  * Fix Fedora build prerequisites - use dnf and add vtk-devel (Fixes #2259) (#2265)
  * Fix CONTRIBUTING.md doc (#2262)
  * Implement OpenEXR image memory read (#2258)
  * Add gaussian splatting spherical harmonics support (#2248)
  * Fix web app default model (#2253)
  * Add SPZ support (#2180)
  * fix temporary up vector convergence (#2249)
  * Support rendering AMR Datasets (#2244)
  * improve gimbal lock avoidance (#2247)
  * doc: Add Ni-g-3l as returning Contributor (#2245)
  * Documentation fixes (#2241)
  * doc: Update build instructions as vtk version support can be misleading (#2233)
  * add default values to `CameraState`'s `__init__` (#2240)
  * remove warning for insignificant animation time differences (#2231)
  * Fix console quiet (#2232)
  * Console: Add a test for quiet console
  * Console: Fix quiet support
  * improve non-trackball interactor rotation (#2217)
  * Style: Use prettier for yml too (#2226)
  * Style: Format all yml
  * Style: Use prettier for yml too
  * doc: Fix a typo with contact@f3d.app (#2211)
  * Rework docker image build (#2209)
  * Small doc improvements (#2203)
  * doc: Add missing BUILD_WASM in dev readme
  * Add 0xfedcafe to f3d contributors (#2200)
  * doc: Use new typical.png from f3d-media (#2194)
  * Fix a typo in PULL_REQUEST_TEMPLATE.md (#2198)
  * Add lgt2x to f3d contributors (#2197)
  * Fix QuakeMDL normal array (#2183)
  * adding exbluesbreaker to MAINTAINERS_AND_CONTRIBUTORS.md (#2195)
  * add `dir` multi-file mode (#2193)
  * Adding  samoncrief to MAINTAINERS_AND_CONTRIBUTORS.md (#2192)
  * Add support for VTKHDF (#2170)
  * doc: Fix a typo with industry sponsors (#2187)
  * Updating VTK (#2186)
  * Add jrushlow to returning contributors (#2185)
  * vtkF3DMetaImporter: Fix coloring for skinning, morphing, and such (#2172)
  * Implement base ior option (#2181)
  * doc: Fix a typo in GOVERNANCE.md (#2182)
  * doc: Fix some typos and improve phrasing (#2179)
  * github: Fix issue template for new style (#2178)
  * Rework Code of Conduct and Governance (#2168)
  * Add ImGui Minimal Console Feature (#2099)
  * imgui: make widget not be brought to front on focus (#2118)
  * doc: Adding email in CoC (#2167)
  * vtkF3DQuakeMDLImporter.cxx: add missing include (#2155)
  * Update externals (#2162)
  * doc: Fix a typo (#2161)
  * Update release issue (#2160)
  * doc: Update roadmapm for 3.2.0 (#2158)
  * doc: Update installation doc
  * Doc: Add doc about linking VTK examples (#2140)
* Wed Apr 16 2025 Michael Vetter <mvetter@suse.com>
- Update to 3.1.0:
  * Fix USD crash on reload (#2148)
  * QuakeMDL: Small fixes (#2145)
  * QuakeMDL: Use PBR lighting and fix texture interpolation (#2135)
  * Fix QuakeMDL animation (#2128)
  * Fix animationManager for dynamic range and single frame (#2129)
  * Application: Catch parsing exception with app options (#2133)
  * Fix: guard DropZone rendering on too small viewport (#2126)
  * libf3d: Fix a crash with ui.axis with external window (#2123)
  * CI: style checks on release too (#2124)
  * CI: Add exceptions for invalid plugin loading on Windows (#2120)
  * Bug Fix: Visual glitch in drop zone border (missing corner pixel) (#2112)
  * libf3d: Depreaction warning on usage of anti_aliasing (#2113)
  * Update version to 3.1.0-RC0 (#2111)
  * QuakeMDL: Fix baselines and module dependencies (#2110)
  * Quake MDL feature (#1591)
  * doc: Improve console doc (#2107)
  * Console: Fix small issues when hiding the console (#2106)
  * Add supersampling anti-aliasing (#2086)
  * imgui: Initial implementation for autocompletion and history in console (#2085)
  * Updating VTK (#2105)
  * assimp: add data validation flag (#2088)
  * Remove prevent skip frame as it is not needed anymore (#2104)
  * f3d-web updates: parse other ui params, loading visual feedback, alert user on error, documentation (#1738)
  * F3D: collpasePath on HDRI drop (#2098)
  * Test: Adding test for collapse on drop
  * F3D: collpasePath on HDRI drop
  * vtkF3DRenderer: Fix a deprecation warning on AddActor2D (#2097)
  * Fix a colormap test (#2096)
  * Colormap parse format (#2066)
  * Replace Dropzone VTKActor by IMGUI  (#1990)
  * Fix JSON key quotes in CONFIGURATION_FILE.md (#2094)
  * Fix a small issue with color formating (#2093)
  * Fix: Add validation for invalid "reset-" option keys in config files (#2083)
  * Add parsing color_t (#2015)
  * Updating dmon to 1.3.7 (#2078)
  * Improve command exception handling (#2065)
  * Remove Android/Wasm VTK master nightly (#2079)
  * Disable UI line antialiasing (#2077)
  * Add colormap type (#2061)
  * Rework Android/Wasm CI (#1950)
  * interactor: Fix triggerCommand to return true on success
  * Fix incorrect handling of invalid arg exception in commands
  * context: Add exception handling (#2064)
  * Rework style checks (#2071)
  * Add OCCT specific reader options (#2059)
  * assimp: Record imported actors from internals (#2058)
  * Adding support for reader specific options (#2060)
  * Fix PWA artifacts (#2057)
  * options: Add support for path using std::filesystem::path
  * F3D: Update help text for new types (#2044)
  * F3D: Fix a small issue with imperative options (#2049)
  * Cache: Add documentation and add XDG support (#2029)
  * Add support for imperative options in configuration files (#2040)
  * format `direction_t` as XYZ when possible (#2041)
  * Initialize temporary up after F3DStarter sets up vector, add test to confirm view does not snap on interaction (#2039)
  * parse mixed `xyz` directions (#2038)
  * doc: Use asciiflow diagram (#2037)
  * F3D: Add support for `-D, --define` and `-R,--reset` CLI option to set/reset libf3d options from CLI (#2035)
  * Add an architecture documentation (#2022)
  * Updating VTK (#2036)
  * wasm: Fix version in package.json and update release template accordingly (#2032)
  * Fix missing set_as_string migration (#2034)
  * Fix wasm option string issue (#2031)
  * Improve testing documentation (#2030)
  * handle arbitrary up vector (#2023)
  * Chore: Update copyright year (#2028)
  * Formatting: Add doc and fix formatting for python files and clang-format in CI (#2027)
  * doc: Update package list on INSTALLATION.md (#2026)
  * Add a new option type: direction_t (#2007)
  * Tests: Update baseline for overlay changes (#2019)
  * Final shader applied on overlay (#1984)
  * Center CheatSheet vertically (#1985)
  * options: Add support for deprecating option in CMake logic (#2011)
  * doc: Fix a ref to a file that has been renamed (#2012)
  * Alias Command (#1895)
  * Update VTK (#2006)
  * test: Testing OBJ with a TGA texture
  * data: Fix incorrect mtl in checkerboard_colorful.obj
  * Tests: Improve cheatsheet testing and limit baselines update (#2001)
  * options: Split tools and generated code for better coverage computation (#2004)
  * options_tools: Improve testing coverage
  * options: Split tools and generated code for better coverage
  * interactor_impl: Improve and fix formatting (#1999)
  * opacity binding (#1972)
  * OBJ: Remove obj.inl logic that is not required since VTK v9.1.0 (#1992)
  * Adding color as a proper option type (#1967)
  * add command remove_file_groups (#1978)
  * Unset optional display value (#1981)
  * Ignore timestamps recording in gzip metadata (#1982)
  * fix zsh completion (#1971)
  * Doc: Stop using vcpkg and simplify getting started for Windows (#1964)
  * application: Report config file locations being checked (#1965)
  * application: Fix list-bindings option initialization (#1966)
  * Improve ci graph (#1938)
  * Simplify VCPKG guide (#1916)
  * Improve fps counter  (#1886)
  * #1741 Rolling camera and then interacting with the view provide incorrect interactions (#1879)
  * add PWA manifest
* Tue Apr 15 2025 Atri Bhattacharya <badshah400@gmail.com>
- Drop BuildRequires: pkgconfig(glew) as it is not used for build
* Tue Jan 21 2025 Michael Vetter <mvetter@suse.com>
- Update to 3.0.0:
  For F3D users:
  * BREAKING CHANGE: Configuration files have changed syntax
  * BREAKING CHANGE: Removed all deprecated options
  * BREAKING CHANGE: --scalars have been split into --scalar-coloring and --coloring-array CLI options
  * BREAKING CHANGE: = must be used for CLI Options, --option value is not supported anymore
  * BREAKING CHANGE: Removed geometry-only and group-geometries and added multi-file-mode option for more flexible loading of multiple files
  * BREAKING CHANGE: There is no headless specific binary release anymore, just use the standard binary with --rendering-backend=egl
  * BREAKING CHANGE: --dry-run has been renamed --no-config
  * BREAKING CHANGE: Esc to quit the app has been changed to Ctrl+Q
  * BREAKING CHANGE: --animation-frame-rate has been replaced by --frame-rate
  * BREAKING CHANGE: Renamed --bg-color into --background-color
  * BREAKING CHANGE: Renamed --comp into --coloring-component
  * BREAKING CHANGE: Removed the ? interaction to dump info, use commands instead
  * BREAKING CHANGE: Renamed --progress into --loading-progress
  * BREAKING CHANGE: Renamed --cells into --coloring-by-cells
  * BREAKING CHANGE: Renamed --range into --coloring-range
  * BREAKING CHANGE: Renamed --bar into --coloring-scalar-bar
  * BREAKING CHANGE: Renamed --inverse into --volume-inverse
  * BREAKING CHANGE: Renamed --samples into --raytracing-samples
  * BREAKING CHANGE: Renamed --denoise into --raytracing-denoise
  * BREAKING CHANGE: Renamed --ref into --reference and --ref-threshold into --reference-threshold
  * BREAKING CHANGE: Renamed --readers-list into --list-readers
  * BREAKING CHANGE: F3D binary release is now built with GCC9
  * Changed the logo!
  * Reworked the UI using ImGui
  * Added support for specifying interactions in config files, see doc
  * Added a --command-script CLI option
  * Added a tiny file dialog, just press Ctrl+O
  * Added support for armature visualization with --armature CLI option (glTF only)
  * Added support for keeping camera position when switching files, just press Ctrl+Arrow
  * Added a ImGui based console to input commands by pressing Esc
  * Added a "Save minimal screenshot" interaction by pressing Shift+F12
  * Added error reporting when loading a file failed for some reason
  * Added missing config file for .brep files
  * Added support for .xbf files
  * Added --input CLI option
  * Added support for libf3d option in configuration files
  * Added support for parsing option based on their type, see the doc
  * Added a --rendering-backend option to select the rendering backend, including headless
  * Added an interaction to rotate camera 90 degrees by pressing 4/6
  * Added an interaction to drop only HDRI (Shift+Drop) and an interaction to drop only 3D files (Ctrl+Drop)
  * Added a --list-bindings CLI option
  * Added a --list-rendering-backends CLI option
  * Added compatibility with VFX CY2025
  * Added commands to print info about scene, coloring, mesh and options
  * Added command to clear the console
  * Added support for expanding tilda (~) into HOME when inputting any path
  * Reworked CLI option parsing to avoid parsing issues
  * Improved --list-readers CLI option output
  * Improved image comparison algorithm
  * Improved options suggestion in the command line
  * Improved many features in F3DWeb as well as adding OCCT and Draco support
  * Improved the webassembly bindings
  * Improved the documentation
  * Improved python bindings
  * Improved startup performance
  * Improved scalar range handling with animation
  * Fixed a crash when opening a glTF file with no textures
  * Fixed an option priority issue with --help
  * Fixed a crash with invalid --animation-index and assimp
  * Fixed an issue where the window displayed an empty filename
  * Fixed an issue where the window resolution was reset when changing file
  * Fixed an issue when reseting the camera and using --camera-index
  * Fixed an issue with --camera-index being overridden by other camera options
  * Fixed an issue when loading a time value outside of the range
  * Fixed issues with screenshot templating
  * Fixed an issue with grid rendering on main axes
  * Fixed an issue where color-bar would show when not needed
  * Fixed an issue with glTF file using URI
  * Fixed --help invalid output
  * Fixed a small issue with F3D dialog being incorrectly named on macOS
  * Fixed an issue where file where open two times on macOS
  For libf3d users:
  * BREAKING CHANGE: All deprecated methods have been removed
  * BREAKING CHANGE: engine::libInformation members have been changed
  * BREAKING CHANGE: options API has been rewritten from scratch, see the doc
  * BREAKING CHANGE: options many options are now optional
  * BREAKING CHANGE: loader API has been replaced by a new class: scene
  * BREAKING CHANGE: engine creation API has been rewritten from scratch and a context class has been added.
  * BREAKING CHANGE: interactor: setKeyPressCallBack, setDropFilesCallBack and timerCallback have been removed
  * BREAKING CHANGE: camera API has been reworked
  * BREAKING CHANGE: image::compare API has been changed
  * BREAKING CHANGE: libf3d API is now using C++17, nodiscard, std::filesystem and std::string_view are now used whenever it makes sense
  * BREAKING CHANGE: Removed support for python 3.8
  * Added an interactor::command* API that lets user control the libf3d behavior more finely
  * Added an interactor::binding* API that lets user control how the libf3d respond to interactions
  * Added an scene::loadAnimationTime API to select animation time to load
  * Added interactor::start arg to control an event loop time and a event loop callback
  * Added python stubs for autocompletion and IDE integration
  * Added suport for python 3.13
  * Fixed an issue with instanciang multiple engines
  * Added an utils::collapsePath
  * Fixed an issue with HiDPI when using the libf3d on Windows
* Thu Jan  2 2025 Michael Vetter <mvetter@suse.com>
- Update to 2.5.1:
  * Fix build compatibility with vtk v9.4.0
* Tue Jul  2 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.5.0:
  For F3D users:
  * Added a Webassembly version available online: https://f3d.app/web
  * Added a "neutral" tone mapping feature
  * Added an screenshot feature when pressing F12, with its dedicated option, --screenshot-filename
  * Added a --final-shader option to customize post-processing.
  * Added a --grid-color option to set the color of the grid
  * Added a --animation-progress option to control if the animation progress bar should be shown
  * Added a --backface-type option to control backface visibility
  * Added a concept of filename template for saving screenshots and outputs
  * Added native menus for macOS
  * Improved documentation all around
  * Reworked config file logic to avoid duplicating of the default config
  * Fixed a long standing issue with FBX skinning animation
  * Fixed zsh completion
  * Fixed an opacity blending issue
  * Fixed a crash when dropping a HDRI while playing an animation
  * Fixed a focus issue on macOS
  * Fixed a high DPI issue on Windows
  For libf3d users:
  * Added an API to control camera pan and zoom
  * Added a tkinter python example
  * Exposed log level in the python API
  For F3D packagers:
  * Fixed compatibility with CMake 3.29.1
  * Fixed compatibility with OCCT 7_8_0
  * Fixed build reproducability by removing a path from the binary
- Add help.patch to fix the build
- Dont manually remove libVTKExtensions*.a. Not needed with
  vtk >= 9.3
* Thu Apr  4 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.4.0:
  For F3D users:
  * Added a new option --point-type used to specify how to display points sprites
  * Add support for 3D Gaussians Splatting in binary .splat format
  * Added ability to cycle through available animations by pressing W hotkey
  * Added display of current animation name within cheatsheet
  * Added orthographic camera projection option (--camera-orthographic) and binding (5)
  * Added proper continuous integration for MacOS ARM64
  * Added support for glTF Draco encoded file
  * Added support for dark title bar on Windows
  * Added support for colormap presets, using --colormap-file option
  * Added a option to reload file automatically when changed on disk (--watch)
  * Added support for streaming output images to stdout, using - filename
  * Added animation support to Alembic plugin
  * Improved OCCT plugin (STEP and IGES files) performance drastically
  * Improved config file parsing so that it is parsed in file order
  * Fixed an issue with blur circle of confusion
  * Fixed an issue with the grid being clipped
  * Fixed an issue with STEP file coloring
  * Fixed an issue when time range was not starting at zero
  * Fixed an issue when record file does not exist
  * Fixed an issue when using --no-render and --hdri
  * Fixed an issue with the Windows thumbnailer with process never properly killed
  * Fixed an issue where OCCT would output to terminal
  * Fixed an issue with FISH completion
  For libf3d users:
  * Added a new option model.point-sprites.type used to specify how
    to display points (only if model.point-sprites.enable is true)
  * Added a image::toTerminalText method to print image to terminal text
  * Added an image metadata API
  * Added a vtkext module for plugin developer, see the documentation
  For F3D packagers:
  * Added a CMake report at the end of configuration
  * Fixed multiple issue with static (BUILD_SHARED_LIBS=OFF) build
  * Fixed a compilation issue with gcc14
  * Fixed a compilation issue with OCCT 7.8.0
* Fri Mar 29 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.3.1:
  * Added --animation-autoplay option (libf3d: scene.animation.autoplay)
    to automatically start animation on file load
  * Added an experimental vdb plugin in order to read .vdb files using OpenVDB
  * Added an usd plugin in order to read .usd files using OpenUSD
  * Added .3mf and .x files support in the assimp plugin
  * Added a small margin between the model and the grid to avoid potential z-fighting
  * Added VTK output to the log when using --verbose=debug for easier debug
  * Reworked the alembic plugin to read Texture Coordinates and Normals for .abc files
  * Improved the reading of EXR files using multi-threading for better performance when loading HDRIs
  * Improved the documentation on https://f3d.app
  * Improved general logging in order to make it easier to understand issues with file and options
  * Fixed potential crashes when reading assimp plugin file formats
  * Fixed --grid-absolute for off-center models
  * Fixed an issue with thumbnail generation showing the log window
  * Fixed many interaction issues on non-Qwerty keyboard layout
  * Fixed handling of filenames containing commas
  * Fixed an issue on Windows where the log window would appear on top of F3D window
  * Fixed crashes with specific .obj file
  * Fixed an issue with incorrect return code when using headless mode or incorrect options
  * Fixed dependency issue with the headless .deb binary release
  * Fixed a crash when using a file with more than 254 bones (Requires OpenGL 4.3)
  * Fixed an issue with Unicode filenames on the title bar on Windows
  * Fixed an issue where focal point picking would generate error messages
  * Changed --verbose into a string based option, eg: --verbose=quiet or
  - -verbose=debug. --verbose is still supported.
  * Changed --no-render behavior so that it doesn't impact verbosity anymore
  * Changed the default configuration file so that translucency support is enabled by default
  * Deprecated --quiet, use --verbose=quiet instead
  * Deprecated --input, use positional argument instead
* Tue Feb 27 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Use the correct documentation's path
* Mon Jan 22 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.3.0:
  For F3D users:
  * Added --animation-autoplay option (libf3d: scene.animation.autoplay) to automatically start animation on file load
  * Added an experimental vdb plugin in order to read .vdb files using OpenVDB
  * Added an usd plugin in order to read .usd files using OpenUSD
  * Added .3mf and .x files support in the assimp plugin
  * Added a small margin between the model and the grid to avoid potential z-fighting
  * Added VTK output to the log when using --verbose=debug for easier debug
  * Reworked the alembic plugin to read Texture Coordinates and Normals for .abc files
  * Improved the reading of EXR files using multi-threading for better performance when loading HDRIs
  * Improved the documentation on https://f3d.app
  * Improved general logging in order to make it easier to understand issues with file and options
  * Fixed potential crashes when reading assimp plugin file formats
  * Fixed --grid-absolute for off-center models
  * Fixed an issue with thumbnail generation showing the log window
  * Fixed many interaction issues on non-Qwerty keyboard layout
  * Fixed handling of filenames containing commas
  * Fixed an issue on Windows where the log window would appear on top of F3D window
  * Fixed crashes with specific .obj file
  * Fixed an issue with incorrect return code when using headless mode or incorrect options
  * Fixed dependency issue with the headless .deb binary release
  * Fixed a crash when using a file with more than 254 bones (Requires OpenGL 4.3)
  * Fixed an issue with Unicode filenames on the title bar on Windows
  * Fixed an issue where focal point picking would generate error messages
  * Changed --verbose into a string based option, eg: --verbose=quiet or --verbose=debug. --verbose is still supported.
  * Changed --no-render behavior so that it doesn't impact verbosity anymore
  * Changed the default configuration file so that translucency support is enabled by default
  * Deprecated --quiet, use --verbose=quiet instead
  * Deprecated --input, use positional argument instead
  For libf3d users:
  * Added scene.animation.autoplay option
  * Added a f3d::image::saveBuffer API to save an image as a file format in memory
  * Fixed the default name of the window
- Remove f3d.rpmlintrc
* Wed Jan 10 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.2.1:
  * Added new options hdri-file, hdri-ambient, hdri-skybox to have more control on the HDRI behavior
  * Added a default HDRI used when providing no hdri-file
  * Added bindings to toggle HDRI ambient lighting (F) and HDRI skybox (J)
  * Added bindings to move the camera to standard locations: 1: Front, 3: Right, 7: Top, 9: Isometric
  * Added Open CASCADE BRep format to the OCCT plugin.
  * Fixed an infamous issue when the Windows thumbnailer always steal the focus
  * Fixed an issue with the binary release when opening draco files
  * Fixed an issue with matcap textures
  * Fixed an issue with HDRI lighting
  * Fixed an issue with HDRI lighting when dropping HDRI after a model
  * Fixed an issue where invalid option would not show on Windows
  * Fixed an issue where previously loaded file would stay visible
  * Fixed an issue when loading invalid EXR file as HDRI
  * Fixed cheatsheet menu rendering under ‘Drop File Instructor’
  * Fixed raytracing rendering issues
  * Improved cheatsheet menu contrast for any background color
  * Improved overall text contrast for any background color
  * Improved performance when changing model and using a HDRI
  * Improved HDRI cache performance
  * Deprecated hdri option
  * Reworked image API to support many file formats to read (EXR, HDR) and write (PNG, JPG, TIF, BMP)
  * Added render.hdri.file, render.hdri.ambient, render.background.skybox options.
  * Deprecated render.background.hdri in favor of new options above
  * Deprecated previous image API
  * Add loader::loadGeometry allowing loading geometry from memory buffers
  * Added a deprecation framework
  * Removed F3D_TESTING_ENABLE_HDRI_TESTS cmake option and merged it with F3D_TESTING_ENABLE_LONG_TIMEOUT_TESTS
  * Added a Getting Started guide for beginners developers
* Wed Jan 10 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.1.0:
  * Reworked Animation support and added many animation related options
  * Added --camera-direction and --camera-zoom-factor and use it in default config file
  * Added --texture-matcap option to load a MatCap texture
  * Added support for opening HDRI background with Drop
  * Added .exr support for HDRI and textures
  * Improved HDRI caching performance
  * Added a EGL headless binary release
  * Added typo suggestion when failing to use the right option name
  * Added --invert-zoom option (libf3d: interactor.invert-zoom) to invert
    zoom direction with right-click on mouse
  * Added support for keeping camera position when reloading a file with UP key
  * Added a --grid-absolute option (libf3d: render.grid.absolute) to
    position the grid instead of being below the model
  * Added a “Drop Zone” when starting F3D without loading a file
  * Added coloring support for STEP files in binary release
  * Fixed an issue on Windows where the error window would popup even with --quiet
  * Fixed an issue with 16 bit and 32 bit textures with assimp plugin
  * Fixed an issue on Windows where errors where not visible
  * Fixed an HDRI issue on reload
  * Fixed a crash when with the progress bar on reloading a file
  * Fixed an issue where certain options from config file would be ignored
  * Fixed a crash with many GLTF files when an array does not have a name
  * Fixed an issue where dropping a duplicate file would change the loaded
    file instead of not doing anything
  * Fixed an issue when loading an unsupported file
  * Fixed an issue with VRML files
  * Improved config file for .ply files
  * Improved config file regex so that they are case-insensitive
  * Improved --up option to support no sign and better validation
  * Improved F3D version reporting about itself and VTK (--version)
  * Improved documentation, testing, help
  * Changed the automatic camera position to a version more close to the data
  * Reduced size of binary release by a factor of two
  * Added vcpkg support for dependency installation
  * Added a F3D_PLUGIN_OCCT_COLORING_SUPPORT CMake variable to control if this
    feature is compiled, default is ON
  * Added SONAME support
  * Added a F3D_PLUGINS_INSTALL_DIR CMake variable to control where to install plugins
  * Added a new module: F3D_MODULE_EXR that depends on openexr
  * Added support to use external cxxopts and external nlohmann-json
  * Fixed a link issue with VTK modules
  * Fixed a @loader_path issue on MacOS
  * Added support for CMAKE_INSTALL_*DIR variables on installation
  * Added support for building against a EGL enabled VTK
  * Fixed a compilation issue with VTK master
- Add build requires for fmt-devel and fast_float-devel
- Set -DF3D_PLUGIN_BUILD_DRACO=OFF for now to fix the build
- Use -DCMAKE_SKIP_INSTALL_RPATH=ON to fix `No valid ELF RPATH or RUNPATH
  entry exists in the file` build failure
- Split out libf3d into subpackage
* Thu Jun 22 2023 Андрей Алыпов <and.november@opensuse.org>
- Update to version 2.0.0:
  * Update F3D Version to 2.0.0 (#744)
  * reorder sections
  * Update LIMITATIONS_AND_TROUBLESHOOTING.md
  * Update copyright year (#742)
  * Update F3D Version to 2.0.0-RC3 (#740)
  * Add a test against segfault (#738)
  * Add doc about unsigned packages (#739)
  * Fix a segfault with down interaction (#737)
  * Update F3D version to RC2 (#736)
  * Fix and update doc (#735)
* Wed Dec 15 2021 Андрей Алыпов <and.november@opensuse.org>
- Update to version 1.2.1
  * Fix format list in documentation
  * typo
  * Fixup
  * initialize quiet
  * Respect output window conf
  * Improving .deb package
  * Handle readers with CMake
  * Rerun failing tests in serial
  * Fix link in readme
  * Added the missing CPACK_PACKAGE_CONTACT
  * Added DEB to cPack generator
  * Fix useless whatis entry in man page.
  * Add shadow warning during strict compil
  * Fix Shadowing
  * Reindent file
  * fix name
  * Improve installation doc
  * SSAO in long timeout to avoid failure on macos
  * Updating VTK for https://gitlab.kitware.com/vtk/vtk/-/merge_requests/8682/
  * Fix an error in codecov conf
  * typo
  * Adding spack package
  * Update website again
  * Adding more badges
* Wed Jul  8 2020 Андрей Алыпов <and.november@opensuse.org>
- initial package (version 1.1.0) for openSUSE
